#!/bin/tcsh
# setup gmt parameters
set region = "-R-106.93451/-106.90916/34.06863/34.08084"
set boundaries = "-BSWnea0.005f.1m/.0025f.05m"
set projection = "-JM9.5i"
set misc = "-K -V -X1i -Y1.5i"
set post_script_name = station_map.ps
# create a basemap
psbasemap $region $projection $boundaries $misc >! $post_script_name
# create a grid file of topography
surface PIC.xyz -GPIC.grd $region -I.0001/.0001
# create a color pallete file for the topography
set misc = "-D -Z -Chaxby"
grd2cpt PIC.grd $misc >! PIC.cpt
# create the gradient file
set misc = "-A0 -M -Nt"
grdgradient PIC.grd -GPIC.grad $misc
# plot the grid
set misc = "-CPIC.cpt -O -V -IPIC.grad -K "
grdimage PIC.grd $projection $region $misc >> $post_script_name
set misc = "-C10 -A20f14 -O -V -K"
grdcontour PIC.grd $projection $region $misc >> $post_script_name
set misc = "-O -K -Sa0.2i -W1p/0 -G0"
psxy $region $projection $misc << END >> $post_script_name
-106.91911 34.07344
END
set misc = "-O -Sa0.1i -W1p/0 -G0/0/255 -K"
psxy $region $projection $misc << END >> $post_script_name
-106.92027 34.073959
-106.92382 34.076003
-106.91941 34.075728
END
set misc = "-O -G0 -K"
pstext $region $projection $misc << END >> $post_script_name
-106.91911 34.07294 14 0 1 TL PIC
END
set misc = "-D4.5i/-0.5i/9i/0.25ih -O -B10/:meters: -K"
psscale -CPIC.cpt $misc >> $post_script_name
set region_inset = "-R-130/-70/26/50"
set projection_inset = "-JM3i"
set misc = "-O -K -G255 -Bnews"
psbasemap $region_inset $projection_inset $misc >> $post_script_name
set misc = "-O -K -Sa0.2 -W1p/0 -G0"
psxy $region_inset $projection_inset $misc << END >> $post_script_name
-106.903 34.0663
END
set misc = "-Dl -Na -W1p/0 -O -K"
pscoast $region_inset $projection_inset $misc >> $post_script_name
set sac_data = IIPC.PC.LHZ.SAC
set misc = "-O -K -G255 -Bnews -Y6i"
set projection_sac_data = "-JX9.5i/.7i"
set region_sac_data = `sac2stdout $sac_data | minmax -I1`
psbasemap $region_sac_data $projection_sac_data $misc >> $post_script_name
set limits = `sac2stdout $sac_data | minmax -C`
set xmin = `echo $limits[1]`
set xmax = `echo $limits[2]`
set ymin = `echo $limits[3]`
set ymax = `echo $limits[4]`
set xtick = `echo $xmax $xmin | awk '{print ($1 - $2) / 20}'`
set ytick = `echo $ymax $ymin | awk '{print ($1 - $2) / 5}'`
set misc = "-O -W2p/20/120/200 -Ba${xtick}f${xtick}/a${ytick}f${ytick}"
sac2stdout $sac_data | psxy $region_sac_data $projection_sac_data $misc >> $post_script_name
set png_name = station_map.png
convert $post_script_name $png_name
echo "$post_script_name converted to $png_name"
exit
